# Dynastes
[![Version](https://img.shields.io/pypi/v/dynastes.svg)](https://pypi.org/project/dynastes/)
![License](https://img.shields.io/pypi/l/keras-bert.svg)

![](https://img.shields.io/badge/keras-tensorflow-blue.svg)
![](https://img.shields.io/badge/keras-tf.keras-blue.svg)

### Description

Collection of various of my custom TensorFlow-Keras 2.0+ layers, utils and such

### Install

```bash
pip install dynastes
```

### Layers
Localized Attention
* Perform attention within "kernels", a bit like convolution

Time-Delay Neural Network Layers

### The name "Dynastes"
Dynastes is a genus of large beetles belonging to the subfamily Dynastinae, rhinoceros [ῥῑνόκερως (rhīnókerōs)] beetles and it is also the name of the son of Heracles and Erato (Thespius 49th daughter). This is a play on the word Keras [κέρας (kéras, “horn”)].

#### Notes about sources:

This repository borrows code heavily from:

[Tensor2Tensor](https://github.com/tensorflow/tensor2tensor/)

[TensorFlow 2.0 Tutorials](https://www.tensorflow.org/tutorials/)

_Code is copied for stability onto this repository and attribution available when possible_